from .wave_gen_1 import WaveGen1
from .wave_gen_2 import WaveGen2
from .wave_mini_gen_1 import WaveMiniGen1
from .wave_plus_gen_1 import WavePlusGen1

DEVICE_MODELS = [
    WaveGen1,
    WaveGen2,
    WaveMiniGen1,
    WavePlusGen1,
]
